@@ -22,53 +22,43 @@
 
 #include "dialog.h"
 
-static GtkCList *cl;
-static int format;
+
+static int flag_separate_output = 0;
 
 static void cancelled(GtkWidget *w, gpointer *d)
 {
 	exit(-1);
 }
 
-static void err_outputter(gpointer d, GtkCList *cl)
+static void err_outputter(gpointer data, gpointer user_data)
 {
-	/*
-	GtkCListRow *r=(GtkCListRow *)d;
-	*/
-	/*
-	 *	Should output the string, or the strings quoted ("")
-	 *	for choice
-	 */
-	char *p;
-	
-	gtk_clist_get_text(cl,GPOINTER_TO_INT(d),0,&p);
-	
-	if(format==0)
-	{
-		write(2, p, strlen(p));
-		write(2, "\n", 1);
-	}
-	else
-	{
-		if(format++>1)
-			write(2," \"", 2);
-		else
-			write(2, "\"", 1);
-		write(2, p, strlen(p));
-		write(2, "\"", 1);
-	}
+	gchar *p;
+
+	g_return_if_fail (data != NULL);
+	g_return_if_fail (GTK_IS_TOGGLE_BUTTON (data));
+
+	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (data))) {
+		p = g_object_get_data (G_OBJECT (data), "item_tag");
+
+		if (flag_separate_output) {
+			write (2, p, strlen (p));
+			write (2, "\n", 1);
+		} else {
+			write (2, "\"", 1);
+			write (2, p, strlen (p));
+			write (2, "\" ", 2);
+		}
+	}		
 }
 
 static void okayed(GtkWidget *w, int button, gpointer *d)
 {
-	if(button==0)
-	{
-		GList *l=GTK_CLIST(cl)->selection;
-		g_list_foreach(l, (GFunc)err_outputter, GTK_CLIST(cl));
-		if(format!=0)
-			write(2,"\n",1);
+	if (button == GTK_RESPONSE_OK) {
+		g_list_foreach (*d, err_outputter, NULL);
+		exit (0);
+	} else if (button == GTK_RESPONSE_CANCEL) {
+		exit (1);	
 	}
-	exit(button);
 }
 
 
@@ -105,19 +95,52 @@ static void print_item(WINDOW * win, const char *tag, const char *item, int stat
 }
 
 
-static gint lwidth=0 , rwidth=0;
-
-static void clist_add(GtkCList *cl, char *l, char *r)
+static void clist_add (GList **list, GtkWidget *box,
+		       char *l, char *r, gboolean select)
 {
-	GdkFont * font = gtk_style_get_font(GTK_WIDGET(cl)->style); 
-	gchar *data[2];
-	
-	data[0]=l;
-	data[1]=r;
-	gtk_clist_append(cl, (gchar **)data);
-	
-	lwidth = MAX(lwidth, gdk_string_width(font, l));	
-	rwidth = MAX(rwidth, gdk_string_width(font, r));	
+	GtkWidget *button;
+	gchar *label;
+
+	label = g_strdup_printf ("%s %s", l, r);
+	button = gtk_check_button_new_with_label (label);
+	gtk_box_pack_start_defaults (GTK_BOX (box), button);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), select);
+	g_object_set_data (G_OBJECT (button), "item_tag" , l);
+	gtk_widget_show (button);
+
+	*list = g_list_append (*list, button);
+	g_free (label);
+	return;
+}
+
+
+static void rlist_add (GList **list, GtkWidget *box,
+		       char *l, char *r, gboolean select)
+{
+	static GtkWidget *first = NULL;
+	GtkWidget *button;
+	gchar *label;
+
+	label = g_strdup_printf ("%s %s", l, r);
+
+	if (!first) {
+		first = gtk_radio_button_new_with_label (NULL, label);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (first), select);
+		gtk_box_pack_start_defaults (GTK_BOX (box), first);
+		g_object_set_data (G_OBJECT (first), "item_tag" , l);
+		gtk_widget_show (first);
+		*list = g_list_append (*list, first);
+	} else {
+		button = gtk_radio_button_new_with_label_from_widget (GTK_RADIO_BUTTON (first), label);
+		gtk_box_pack_start_defaults (GTK_BOX (box), button);
+		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), select);
+		g_object_set_data (G_OBJECT (button), "item_tag" , l);
+		gtk_widget_show (button);
+		*list = g_list_append (*list, button);
+	}
+
+	g_free (label);
+	return;
 }
 
 /*
@@ -129,75 +152,80 @@ int dialog_checklist(const char *title, const char *prompt, int height, int widt
 		     int separate_output)
 {
 	int i, x, y, cur_x, cur_y, box_x, box_y;
-	int key = 0, button = 0, choice = 0, scroll = 0, max_choice,
+	int key = 0, button = GTK_RESPONSE_OK, choice = 0, scroll = 0, max_choice,
 	*status;
 	WINDOW *dialog, *list;
 
-	if (gnome_mode) {
-		GtkWidget *w = gnome_dialog_new(title,
-					GNOME_STOCK_BUTTON_OK,
-					GNOME_STOCK_BUTTON_CANCEL, NULL);
-		GtkWidget *hbox, *vbox, *sw;
+	flag_separate_output = separate_output;
 
-		gnome_dialog_set_default(GNOME_DIALOG(w), 0);
-		gnome_dialog_set_close(GNOME_DIALOG(w), TRUE);
-		gtk_window_set_title(GTK_WINDOW(w), title);
-
-		hbox = gtk_hbox_new(FALSE, 0);
-		vbox = gtk_vbox_new(FALSE, 0);
-
-		label_autowrap(vbox, prompt, width);
-
-		sw=gtk_scrolled_window_new (NULL, NULL);
-		cl=GTK_CLIST(gtk_clist_new(2));
-		gtk_container_add (GTK_CONTAINER (sw), GTK_WIDGET (cl));
+  	if (gnome_mode) {
+ 		GtkWidget *vbox, *dialog, *sw;
+ 		GtkWidget *text;
+ 		GList *list = NULL;
 		
-		if(flag!=FLAG_CHECK)
-		{
-			format=0;
-			gtk_clist_set_selection_mode(cl, GTK_SELECTION_BROWSE);
-		}
-		else
-		{
-			format=1;
-			gtk_clist_set_selection_mode(cl, GTK_SELECTION_MULTIPLE);
-		}
-		gtk_scrolled_window_set_policy (
-			GTK_SCROLLED_WINDOW (sw),
-			GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-		gtk_clist_freeze(cl);
-		gtk_clist_set_shadow_type(cl, GTK_SHADOW_IN);		
+ 		dialog  = gtk_dialog_new_with_buttons (title,
+  			NULL,
+  			GTK_DIALOG_DESTROY_WITH_PARENT,
+  			GTK_STOCK_CANCEL,
+  			GTK_RESPONSE_CANCEL,
+			GTK_STOCK_OK,
+ 			GTK_RESPONSE_OK,
+  			NULL);
+ 		gtk_dialog_set_default_response (GTK_DIALOG(dialog),
+ 						 GTK_RESPONSE_OK);
+  
+		label_autowrap (GTK_DIALOG (dialog)->vbox, prompt, width);
 
-		for (i = 0; i < item_no; i++) {
-			char *x = (char *)items[3 * i];
-			char *y = (char *)items[3 * i + 1];
-			clist_add(cl, x, y);
-			if(strcasecmp(items[3*i+2],"on")==0)
-			{
-				gtk_clist_select_row(cl, i, -1);
-			}
-		}
+		sw = gtk_scrolled_window_new (NULL, NULL);
+ 		gtk_box_pack_start_defaults (
+ 			GTK_BOX (GTK_DIALOG (dialog)->vbox), sw);
+		gtk_widget_show (sw);
 
-		gtk_clist_set_column_width(cl, 0, lwidth + 10);
-		gtk_clist_set_column_width(cl, 1, rwidth);  		
-		gtk_clist_thaw(cl);
-		gtk_widget_set_usize(GTK_WIDGET(cl), lwidth+rwidth+30, 8*list_height+40);
+ 		vbox = gtk_vbox_new (FALSE, 0);
+ 		gtk_scrolled_window_add_with_viewport (
+			GTK_SCROLLED_WINDOW (sw), vbox);
+ 		gtk_widget_show (vbox);
+ 
+ 		/*
+ 		 * Add the options.
+ 		 */
+  		for (i = 0; i < item_no; i++) {
+  			char *x = (char *)items[3 * i];
+  			char *y = (char *)items[3 * i + 1];
+ 			char *z = (char *)items[3 * i + 2];
+ 			gboolean select;
+  
+ 			/*
+ 			 * Check wether op is "on" or "off".
+ 			 */
+			if (!strcmp (z, "on") || !strcmp (z, "ON"))
+ 				select = TRUE;
+ 			else if (!strcmp (z, "off") || !strcmp (z, "OFF"))
+ 				select = FALSE;
+ 			else
+ 				/*
+ 				 * Why -10? See the second last if statment
+				 * in dialog.c (main). Prints Usage.
+ 				 */
+ 				return -10;
+ 		       
+ 
+ 			if (flag == FLAG_CHECK)
+ 				clist_add (&list, vbox, x, y, select);
+ 		        else
+ 				rlist_add (&list, vbox, x, y, select);
+ 		}
 
-		gtk_box_pack_start(GTK_BOX(vbox), GTK_WIDGET(sw), TRUE, TRUE, 0);
-		gtk_box_pack_start(GTK_BOX(hbox), vbox, TRUE, TRUE, 0);
-
-		gtk_box_pack_start(GTK_BOX(GNOME_DIALOG(w)->vbox),
-				   hbox,
-				   TRUE, TRUE, GNOME_PAD);
-		gtk_window_position(GTK_WINDOW(w), GTK_WIN_POS_CENTER);
-		gtk_signal_connect(GTK_OBJECT(w), "destroy",
-			GTK_SIGNAL_FUNC(cancelled), NULL);
-		gtk_signal_connect(GTK_OBJECT(w), "clicked",
-			GTK_SIGNAL_FUNC(okayed), NULL);
-		gtk_widget_show_all(w);
-		gtk_main();
-		return 0;
-	}
+ 		gtk_window_set_position (GTK_WINDOW (dialog),
+ 					 GTK_WIN_POS_CENTER);
+ 		gtk_signal_connect(GTK_OBJECT(dialog), "close",
+  			GTK_SIGNAL_FUNC(cancelled), NULL);
+ 		gtk_signal_connect(GTK_OBJECT(dialog), "response",
+ 			GTK_SIGNAL_FUNC(okayed), &list);
+ 		gtk_widget_show_all (dialog);
+  		gtk_main();
+  		return 0;
+  	}
 	checkflag = flag;
 
 	/* Allocate space for storing item on/off status */
@@ -486,16 +514,20 @@ int dialog_checklist(const char *title, const char *prompt, int height, int widt
 			return 1;
 		case M_EVENT + 'o':	/* mouse enter... */
 		case M_EVENT + 'c':	/* use the code for toggling */
-			button = (key == M_EVENT + 'o');
+			if(key == M_EVENT + 'o')
+				button = GTK_RESPONSE_CANCEL;
+			else
+				button = GTK_RESPONSE_OK;
+
 		case TAB:
 		case KEY_LEFT:
 		case KEY_RIGHT:
-			if (!button) {
-				button = 1;	/* "Cancel" button selected */
+			if (button == GTK_RESPONSE_OK) {			 
+				button = GTK_RESPONSE_CANCEL;	/* "Cancel" button selected */
 				print_button(dialog, "  OK  ", y, x, FALSE);
 				print_button(dialog, "Cancel", y, x + 14, TRUE);
 			} else {
-				button = 0;	/* "OK" button selected */
+				button = GTK_RESPONSE_OK;	/* "OK" button selected */
 				print_button(dialog, "Cancel", y, x + 14, FALSE);
 				print_button(dialog, "  OK  ", y, x, TRUE);
 			}
@@ -504,7 +536,7 @@ int dialog_checklist(const char *title, const char *prompt, int height, int widt
 		case ' ':
 		case '\n':
 			delwin(dialog);
-			if (!button)
+			if (!GTK_RESPONSE_OK)
 				for (i = 0; i < item_no; i++)
 					if (status[i]) {
 						if (flag == FLAG_CHECK) {
