@@ -81,8 +81,9 @@ static FindOptionTemplate templates[] = {
 	{ SEARCH_CONSTRAINT_TEXT, "'!' -name '*%s*'", N_("Na_me does not contain"), FALSE },
 	{ SEARCH_CONSTRAINT_TEXT, "-regex '%s'", N_("Name matches regular e_xpression"), FALSE }, 
 	{ SEARCH_CONSTRAINT_SEPARATOR, NULL, NULL, TRUE },
+	{ SEARCH_CONSTRAINT_BOOL, "SHOW_HIDDEN_FILES", N_("Show hidden files and folders"), FALSE },
 	{ SEARCH_CONSTRAINT_BOOL, "-follow", N_("Follow symbolic links"), FALSE },
-	{ SEARCH_CONSTRAINT_BOOL, "-xdev", N_("Include other filesystems"), FALSE },
+	{ SEARCH_CONSTRAINT_BOOL, "INCLUDE_OTHER_FILESYSTEMS", N_("Include other filesystems"), FALSE },
 	{ SEARCH_CONSTRAINT_END, NULL, NULL, FALSE}
 }; 
 
@@ -110,7 +111,8 @@ enum {
 	SEARCH_CONSTRAINT_SEPARATOR_03,	
 	SEARCH_CONSTRAINT_FILE_IS_NOT_NAMED,
 	SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION,
-	SEARCH_CONSTRAINT_SEPARATOR_04,	
+	SEARCH_CONSTRAINT_SEPARATOR_04,
+	SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS,
 	SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS,
 	SEARCH_CONSTRAINT_SEARCH_OTHER_FILESYSTEMS,
 	SEARCH_CONSTRAINT_MAXIMUM_POSSIBLE
@@ -130,6 +132,7 @@ struct _PoptArgument {
 	gboolean 	empty;
 	gchar		*notnamed;
 	gchar		*regex;
+	gboolean	hidden;
 	gboolean	follow;
 	gboolean	allmounts;
 	gchar 		*sortby;
@@ -154,6 +157,7 @@ struct poptOption options[] = {
   	{ "nouser", '\0', POPT_ARG_NONE, &PoptArgument.nouser, 0, NULL, NULL},
   	{ "notnamed", '\0', POPT_ARG_STRING, &PoptArgument.notnamed, 0, NULL, NULL},
   	{ "regex", '\0', POPT_ARG_STRING, &PoptArgument.regex, 0, NULL, NULL},
+	{ "hidden", '\0', POPT_ARG_NONE, &PoptArgument.hidden, 0, NULL, NULL},
   	{ "follow", '\0', POPT_ARG_NONE, &PoptArgument.follow, 0, NULL, NULL},
   	{ "allmounts", '\0', POPT_ARG_NONE, &PoptArgument.allmounts, 0, NULL, NULL},
   	{ NULL,'\0', 0, NULL, 0, NULL, NULL}
@@ -205,6 +209,55 @@ setup_case_insensitive_arguments (void)
 	}
 	g_free (cmd_stderr);
 }
+  
+gchar *
+setup_find_name_options (gchar *filename)
+{
+	/* This function builds the name options for the find command.  This in
+	   done to insure that the find command returns hidden files and folders. */
+
+	GString *command;
+	command = g_string_new ("");
+
+	if (strstr(filename, "*") == NULL) {
+
+		if ((strlen(filename) == 0) || (filename[0] != '.')) {
+	 		g_string_append_printf (command, "\\( %s '*%s*' -o %s '.*%s*' \\) ", 
+					find_command_default_name_option, filename,
+					find_command_default_name_option, filename);
+		}
+		else {
+			g_string_append_printf (command, "\\( %s '*%s*' -o %s '.*%s*' -o %s '%s*' \\) ", 
+					find_command_default_name_option, filename,
+					find_command_default_name_option, filename,
+					find_command_default_name_option, filename);
+		}
+	}
+	else {
+		if (filename[0] == '.') {
+			g_string_append_printf (command, "\\( %s '%s' -o %s '.*%s' \\) ", 
+					find_command_default_name_option, filename,
+					find_command_default_name_option, filename);	
+		}
+		else if (filename[0] != '*') {
+			g_string_append_printf (command, "%s '%s' ", 
+					find_command_default_name_option, filename);
+		}
+		else {
+			if ((strlen(filename) >= 1) && (filename[1] == '.')) {
+				g_string_append_printf (command, "\\( %s '%s' -o %s '%s' \\) ", 
+					find_command_default_name_option, filename,
+					find_command_default_name_option, &filename[1]);
+			}
+			else {
+				g_string_append_printf (command, "\\( %s '%s' -o %s '.%s' \\) ", 
+					find_command_default_name_option, filename,
+					find_command_default_name_option, filename);
+			}
+		}
+	}
+	return g_string_free (command, FALSE);
+}
 
 gchar *
 build_search_command (void)
@@ -248,6 +301,7 @@ build_search_command (void)
 	search_command.look_in_folder = g_strdup(look_in_folder_locale);
 	
 	command = g_string_new ("");
+	search_command.show_hidden_files = FALSE;
 	
 	if (GTK_WIDGET_VISIBLE(interface.additional_constraints) == FALSE) {
 	
@@ -281,10 +335,9 @@ build_search_command (void)
 		file_is_named_escaped = escape_single_quotes (file_is_named_locale);
 		search_command.file_is_named_pattern = g_strdup(file_is_named_utf8);
 		
-		g_string_append_printf (command, "find \"%s\" '!' -type p %s '%s' ", 
-					 	look_in_folder_locale,
-						find_command_default_name_option,
-						file_is_named_escaped);
+		g_string_append_printf (command, "find \"%s\" '!' -type p  %s", 
+					look_in_folder_locale,
+					setup_find_name_options (file_is_named_escaped));
 	
 		for (list = interface.selected_constraints; list != NULL; list = g_list_next (list)) {
 			
@@ -292,13 +345,16 @@ build_search_command (void)
 						
 			switch (templates[constraint->constraint_id].type) {
 			case SEARCH_CONSTRAINT_BOOL:
-				if (strcmp (templates[constraint->constraint_id].option, "-xdev") != 0) {
-					g_string_append_printf(command, "%s ",
-						       templates[constraint->constraint_id].option);
+				if (strcmp (templates[constraint->constraint_id].option, "INCLUDE_OTHER_FILESYSTEMS") == 0) {
+					disable_mount_argument = TRUE;
+				}
+				else if (strcmp (templates[constraint->constraint_id].option, "SHOW_HIDDEN_FILES") == 0) {
+					search_command.show_hidden_files = TRUE;
 				}
 				else {
-					disable_mount_argument = TRUE;
-				} 
+					g_string_append_printf(command, "%s ",
+						templates[constraint->constraint_id].option);
+				}
 				break;
 			case SEARCH_CONSTRAINT_TEXT:
 				if (strcmp (templates[constraint->constraint_id].option, "-regex '%s'") == 0) {
@@ -472,6 +528,7 @@ add_no_files_found_message (GtkListStore 	*store,
 static GtkWidget *
 make_list_of_templates (void)
 {
+	gboolean ACTIVATE_MENU_OPTION = TRUE;
 	GtkWidget *menu;
 	GtkWidget *menuitem;
 	GtkWidget *separator;
@@ -505,6 +562,12 @@ make_list_of_templates (void)
 		if (templates[i].is_selected == TRUE) {
 			gtk_widget_set_sensitive (menuitem, FALSE);
 		}
+		else {
+			if (ACTIVATE_MENU_OPTION == TRUE) {
+				ACTIVATE_MENU_OPTION = FALSE;
+				g_signal_emit_by_name (G_OBJECT(menuitem), "activate", NULL);
+			}
+		}
 	}
 	return menu;
 }
@@ -621,6 +684,10 @@ set_constraint_gconf_boolean (gint constraint_id, gboolean flag)
 			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/name_matches_regular_expression",
 	   		       	       	               flag);
 			break;
+		case SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS:
+			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/show_hidden_files_and_folders",
+	   		       	       	               flag);
+			break;
 		case SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS:
 			gsearchtool_gconf_set_boolean ("/apps/gnome-search-tool/follow_symbolic_links",
 	   		       	       	               flag);
@@ -801,6 +868,10 @@ handle_popt_args (void)
 		add_constraint (SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION, 
 				PoptArgument.regex, TRUE);
 	}
+	if (PoptArgument.hidden == TRUE) {
+		popt_args_found = TRUE;
+		add_constraint (SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS, NULL, TRUE);
+	}
 	if (PoptArgument.follow == TRUE) {
 		popt_args_found = TRUE;
 		add_constraint (SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS, NULL, TRUE); 
@@ -992,6 +1063,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 		gnome_appbar_push (GNOME_APPBAR (interface.status_bar), status_bar_string);
 		g_source_remove (search_data->timeout);
 
+		gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.find_button);
 		gtk_widget_set_sensitive (interface.additional_constraints, TRUE);
 		gtk_widget_set_sensitive (interface.disclosure, TRUE);
 		gtk_widget_set_sensitive (interface.table, TRUE);
@@ -1142,7 +1214,7 @@ spawn_search_command (gchar *command)
 	}	
 
 	if (!g_spawn_async_with_pipes (g_get_home_dir (), argv, NULL, 
-				       (G_SPAWN_SEARCH_PATH | G_SPAWN_DO_NOT_REAP_CHILD),
+				       G_SPAWN_SEARCH_PATH,
 				       NULL, NULL, &search_command.pid, NULL, &child_stdout, 
 				       &child_stderr, &error)) {
 		GtkWidget *dialog;
@@ -1168,6 +1240,7 @@ spawn_search_command (gchar *command)
 	search_command.lock = TRUE;
 	search_command.running = RUNNING; 
 
+	gtk_window_set_default (GTK_WINDOW(interface.main_window), interface.stop_button);
 	gtk_widget_show (interface.stop_button);
 	gtk_widget_set_sensitive (interface.stop_button, TRUE);
 	gtk_widget_hide (interface.find_button);
@@ -1206,7 +1279,7 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 	GtkWidget *entry;
 	GtkWidget *button;
 	
-	hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
+	hbox = gtk_hbox_new (FALSE, 12);
 
 	switch(templates[opt->constraint_id].type) {
 	case SEARCH_CONSTRAINT_BOOL:
@@ -1214,7 +1287,7 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 			gchar *text = remove_mnemonic_character (templates[opt->constraint_id].desc);
 			gchar *desc = g_strconcat (LEFT_LABEL_SPACING, _(text), ".", NULL);
 			label = gtk_label_new (desc);
-			gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+			gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 			g_free (desc);
 			g_free (text);
 		}
@@ -1227,7 +1300,7 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 			label = gtk_label_new_with_mnemonic (desc);
 			g_free (desc);
 		}
-		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+		gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 0);
 		
 		if (templates[opt->constraint_id].type == SEARCH_CONSTRAINT_TEXT) {
 			entry = gtk_entry_new();
@@ -1267,17 +1340,18 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 				  NULL);
 				  
 		/* add label and text field */
-		gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, GNOME_PAD_SMALL);
+		gtk_box_pack_start(GTK_BOX(hbox), entry, TRUE, TRUE, 0);
 		
 		break;
 	default:
 		/* This should never happen.  If it does, there is a bug */
 		label = gtk_label_new("???");
-		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, GNOME_PAD_SMALL);
+		gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE, 0);
 	        break;
 	}
 	
-	button = gtk_button_new_from_stock(GTK_STOCK_REMOVE); 
+	button = gtk_button_new_from_stock(GTK_STOCK_REMOVE);
+	GTK_WIDGET_UNSET_FLAGS (button, GTK_CAN_DEFAULT); 
 	g_signal_connect(G_OBJECT(button), "clicked",
 			 G_CALLBACK(remove_constraint_cb), opt);
         gtk_size_group_add_widget (interface.constraint_size_group, button);
@@ -1306,7 +1380,7 @@ add_constraint (gint constraint_id, gchar *value, gboolean show_constraint)
 		}
 	} 
 	
-	interface.geometry.min_height += 30; 
+	interface.geometry.min_height += 35; 
 	gtk_window_set_geometry_hints (GTK_WINDOW(interface.main_window), 
 				       GTK_WIDGET(interface.main_window),
 				       &interface.geometry, GDK_HINT_MIN_SIZE);
@@ -1329,30 +1403,24 @@ static GtkWidget *
 create_additional_constraint_section (void)
 {
 	GtkWidget *hbox;
-	GtkWidget *vbox1; 
-	GtkWidget *vbox2;
 	GtkWidget *label;
 	gchar *desc;
 
-	vbox1 = gtk_vbox_new (FALSE, 0);
-	gtk_container_set_border_width (GTK_CONTAINER(vbox1), 0);
+	interface.constraint = gtk_vbox_new (FALSE, 6);	
+
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_end (GTK_BOX(interface.constraint), hbox, FALSE, FALSE, 0);
 
-	interface.constraint = gtk_vbox_new (FALSE, 0); 
-	vbox2 = gtk_vbox_new (FALSE, 0);
-	hbox = gtk_hbox_new (FALSE, 0);
-	
-	gtk_box_pack_end (GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
-	
 	desc = g_strconcat (LEFT_LABEL_SPACING, _("A_vailable options:"), NULL);
 	label = gtk_label_new_with_mnemonic (desc);
 	g_free (desc);
 
-	gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, 0);
 	
 	interface.constraint_menu = gtk_option_menu_new ();
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), GTK_WIDGET(interface.constraint_menu));
 	gtk_option_menu_set_menu (GTK_OPTION_MENU(interface.constraint_menu), make_list_of_templates());
-	gtk_box_pack_start (GTK_BOX(hbox), interface.constraint_menu, TRUE, TRUE, GNOME_PAD);
+	gtk_box_pack_start (GTK_BOX(hbox), interface.constraint_menu, TRUE, TRUE, 0);
 
 	if (interface.is_gail_loaded)
 	{
@@ -1362,6 +1430,7 @@ create_additional_constraint_section (void)
 	}
 
 	interface.add_button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+	GTK_WIDGET_UNSET_FLAGS (interface.add_button, GTK_CAN_DEFAULT);
 	interface.constraint_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
 	gtk_size_group_add_widget (interface.constraint_size_group, interface.add_button);
 	
@@ -1369,12 +1438,8 @@ create_additional_constraint_section (void)
 			  G_CALLBACK(add_constraint_cb), NULL);
 	
 	gtk_box_pack_end (GTK_BOX(hbox), interface.add_button, FALSE, FALSE, 0); 
-		
-	gtk_box_pack_start (GTK_BOX(vbox1), interface.constraint, TRUE, TRUE, GNOME_PAD_SMALL);
 	
-	gtk_container_add (GTK_CONTAINER(vbox1), GTK_WIDGET(vbox2));
-	
-	return vbox1;
+	return interface.constraint;
 }
 
 GtkWidget *
@@ -1386,14 +1451,14 @@ create_search_results_section (void)
 	GtkTreeViewColumn *column;	
 	GtkCellRenderer   *renderer;
 	
-	vbox = gtk_vbox_new (FALSE, 0);	
+	vbox = gtk_vbox_new (FALSE, 6);	
 	
-	label = gtk_label_new_with_mnemonic (_("S_earch Results"));
+	label = gtk_label_new_with_mnemonic (_("S_earch results:"));
 	g_object_set (G_OBJECT(label), "xalign", 0.0, NULL);
-	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	
 	window = gtk_scrolled_window_new (NULL, NULL);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_IN);	
+	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(window), GTK_SHADOW_NONE);	
 	gtk_container_set_border_width (GTK_CONTAINER(window), 0);
 	gtk_widget_set_size_request (window, 530, 160); 
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(window),
@@ -1538,18 +1603,18 @@ create_main_window (void)
 	GtkWidget 	*window;
 	GtkWidget	*image;
 
-	window = gtk_vbox_new (FALSE, GNOME_PAD_SMALL);
-	gtk_container_set_border_width (GTK_CONTAINER(window), GNOME_PAD);
+	window = gtk_vbox_new (FALSE, 6);	
+	gtk_container_set_border_width (GTK_CONTAINER(window), 12);
 
-	hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, FALSE, GNOME_PAD_SMALL);
+	hbox = gtk_hbox_new (FALSE, 12);
+	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, FALSE, 0);
 	
 	image = gtk_image_new_from_stock (GNOME_SEARCH_TOOL_STOCK, gsearchtool_icon_size);
-	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 	
 	interface.table = gtk_table_new (2, 2, FALSE);
-	gtk_table_set_row_spacings (GTK_TABLE(interface.table), GNOME_PAD);
-	gtk_table_set_col_spacings (GTK_TABLE(interface.table), GNOME_PAD);
+	gtk_table_set_row_spacings (GTK_TABLE(interface.table), 6);
+	gtk_table_set_col_spacings (GTK_TABLE(interface.table), 12);
 	gtk_container_add (GTK_CONTAINER(hbox), interface.table);
 	
 	label = gtk_label_new_with_mnemonic (_("_Name contains:"));
@@ -1623,24 +1688,26 @@ create_main_window (void)
 	
 	interface.results = create_search_results_section ();
 	gtk_widget_set_sensitive (GTK_WIDGET(interface.results), FALSE);
-	gtk_box_pack_start (GTK_BOX(window), interface.results, TRUE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(window), interface.results, TRUE, TRUE, 0);
 	
 	hbox = gtk_hbutton_box_new ();
 	gtk_button_box_set_layout (GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
-	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, TRUE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, FALSE, 0);
 
-	gtk_box_set_spacing (GTK_BOX(hbox), GNOME_PAD);
+	gtk_box_set_spacing (GTK_BOX(hbox), 6);
 	button = gtk_button_new_from_stock (GTK_STOCK_HELP);
-	gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, GNOME_PAD_SMALL);
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
+	gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	gtk_button_box_set_child_secondary (GTK_BUTTON_BOX(hbox), button, TRUE);
 	g_signal_connect (G_OBJECT(button), "clicked",
 			  G_CALLBACK(help_cb), NULL);
 	
 	button = gtk_button_new_from_stock (GTK_STOCK_CLOSE);
+	GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
 	g_signal_connect (G_OBJECT(button), "clicked",
 			  G_CALLBACK(quit_cb), NULL);
 	
-	gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_start (GTK_BOX(hbox), button, FALSE, FALSE, 0);
 	
 	interface.find_button = gtk_button_new_from_stock (GTK_STOCK_FIND);
 	interface.stop_button = gtk_button_new_from_stock (GTK_STOCK_STOP);
@@ -1651,8 +1718,8 @@ create_main_window (void)
 			  G_CALLBACK(size_allocate_cb), NULL);
 	g_signal_connect (G_OBJECT(interface.stop_button),"clicked",
 			  G_CALLBACK(click_stop_cb), NULL);
-	gtk_box_pack_end (GTK_BOX(hbox), interface.stop_button, FALSE, FALSE, GNOME_PAD_SMALL);
-	gtk_box_pack_end (GTK_BOX(hbox), interface.find_button, FALSE, FALSE, GNOME_PAD_SMALL);
+	gtk_box_pack_end (GTK_BOX(hbox), interface.stop_button, FALSE, FALSE, 0);
+	gtk_box_pack_end (GTK_BOX(hbox), interface.find_button, FALSE, FALSE, 0);
 	gtk_widget_set_sensitive (interface.stop_button, FALSE);
 	gtk_widget_set_sensitive (interface.find_button, TRUE);
 	
@@ -1773,6 +1840,9 @@ set_clone_command (gint *argcp, gchar ***argvp, gpointer client_data)
 				locale = g_locale_from_utf8 (constraint->data.text, -1, NULL, NULL, NULL);
 				argv[i++] = g_strdup_printf ("--regex=%s", locale);
 				break;
+			case SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS:
+				argv[i++] = g_strdup ("--hidden");
+				break;
 			case SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS:
 				argv[i++] = g_strdup ("--follow");
 				break;
@@ -1843,6 +1913,10 @@ handle_gconf_settings (void)
 		add_constraint (SEARCH_CONSTRAINT_FILE_MATCHES_REGULAR_EXPRESSION, "", FALSE); 
 	}
 	
+	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/show_hidden_files_and_folders") == TRUE) {
+		add_constraint (SEARCH_CONSTRAINT_SHOW_HIDDEN_FILES_AND_FOLDERS, NULL, FALSE); 
+	}
+	
 	if (gsearchtool_gconf_get_boolean ("/apps/gnome-search-tool/follow_symbolic_links") == TRUE) {
 		add_constraint (SEARCH_CONSTRAINT_FOLLOW_SYMBOLIC_LINKS, NULL, FALSE); 
 	}
